@@ -10,60 +10,38 @@ import posixpath
 import shutil
 import stat
 import sys
+import typing
 import time
 import unicodedata
 import warnings
 
-import six
-from six.moves import urllib_parse
-from six.moves.urllib import request as urllib_request
+from pathlib import Path
+from tempfile import NamedTemporaryFile, TemporaryDirectory
+from typing import Optional, Callable
+from urllib import parse as urllib_parse
+from urllib import request as urllib_request
 
-from .backports.tempfile import _TemporaryFileWrapper
-from .compat import (
-    IS_TYPE_CHECKING,
-    FileNotFoundError,
-    Path,
-    PermissionError,
-    ResourceWarning,
-    TemporaryDirectory,
-    _fs_encoding,
-    _NamedTemporaryFile,
-    finalize,
-    fs_decode,
-    fs_encode,
-)
+from urllib.parse import quote
 
-# fmt: off
-if six.PY3:
-    from urllib.parse import quote_from_bytes as quote
-else:
-    from urllib import quote
-# fmt: on
-
-
-if IS_TYPE_CHECKING:
+if typing.TYPE_CHECKING:
     from types import TracebackType
     from typing import (
         Any,
         AnyStr,
         ByteString,
-        Callable,
         Generator,
         Iterator,
         List,
-        Optional,
         Text,
         Tuple,
         Type,
         Union,
     )
 
-    if six.PY3:
-        TPath = os.PathLike
-    else:
-        TPath = Union[str, bytes]
+    TPath = os.PathLike
     TFunc = Callable[..., Any]
 
+
 __all__ = [
     "check_for_unc_path",
     "get_converted_relative_path",
@@ -97,21 +75,17 @@ if os.name == "nt":
 def unicode_path(path):
     # type: (TPath) -> Text
     # Paths are supposed to be represented as unicode here
-    if six.PY2 and isinstance(path, six.binary_type):
-        return path.decode(_fs_encoding)
     return path
 
 
 def native_path(path):
     # type: (TPath) -> str
-    if six.PY2 and isinstance(path, six.text_type):
-        return path.encode(_fs_encoding)
     return str(path)
 
 
 # once again thank you django...
 # https://github.com/django/django/blob/fc6b90b/django/utils/_os.py
-if six.PY3 or os.name == "nt":
+if os.name == "nt":
     abspathu = os.path.abspath
 else:
 
@@ -121,7 +95,7 @@ else:
         the current working directory, thus avoiding a UnicodeDecodeError in
         join when the cwd has non-ASCII characters."""
         if not os.path.isabs(path):
-            path = os.path.join(os.getcwdu(), path)
+            path = os.path.join(os.getcwd(), path)
         return os.path.normpath(path)
 
 
@@ -167,7 +141,7 @@ def normalize_drive(path):
     from .misc import to_text
 
     if os.name != "nt" or not (
-        isinstance(path, six.string_types) or getattr(path, "__fspath__", None)
+        isinstance(path, str) or getattr(path, "__fspath__", None)
     ):
         return path  # type: ignore
 
@@ -200,13 +174,13 @@ def path_to_url(path):
         # XXX: This enables us to handle half-surrogates that were never
         # XXX: actually part of a surrogate pair, but were just incidentally
         # XXX: passed in as a piece of a filename
-        quoted_path = quote(fs_encode(path))
-        return fs_decode("file:///{}:{}".format(drive, quoted_path))
+        quoted_path = quote(path, errors="backslashreplace")
+        return "file:///{}:{}".format(drive, quoted_path)
     # XXX: This is also here to help deal with incidental dangling surrogates
     # XXX: on linux, by making sure they are preserved during encoding so that
     # XXX: we can urlencode the backslash correctly
-    bytes_path = to_bytes(normalized_path, errors="backslashreplace")
-    return fs_decode("file://{}".format(quote(bytes_path)))
+    # bytes_path = to_bytes(normalized_path, errors="backslashreplace")
+    return "file://{}".format(quote(path, errors="backslashreplace"))
 
 
 def url_to_path(url):
@@ -244,7 +218,7 @@ def is_file_url(url):
 
     if not url:
         return False
-    if not isinstance(url, six.string_types):
+    if not isinstance(url, str):
         try:
             url = url.url
         except AttributeError:
@@ -260,8 +234,6 @@ def is_readonly_path(fn):
     Permissions check is `bool(path.stat & stat.S_IREAD)` or `not
     os.access(path, os.W_OK)`
     """
-
-    fn = fs_decode(fs_encode(fn))
     if os.path.exists(fn):
         file_stat = os.stat(fn).st_mode
         return not bool(file_stat & stat.S_IWRITE) or not os.access(fn, os.W_OK)
@@ -269,6 +241,7 @@ def is_readonly_path(fn):
 
 
 def mkdir_p(newdir, mode=0o777):
+    # This exists in shutil already
     # type: (TPath, int) -> None
     """Recursively creates the target directory and all of its parents if they
     do not already exist.  Fails silently if they do.
@@ -276,12 +249,11 @@ def mkdir_p(newdir, mode=0o777):
     :param str newdir: The directory path to ensure
     :raises: OSError if a file is encountered along the way
     """
-    newdir = fs_decode(fs_encode(newdir))
     if os.path.exists(newdir):
         if not os.path.isdir(newdir):
             raise OSError(
                 "a file with the same name as the desired dir, '{}', already exists.".format(
-                    fs_decode(newdir)
+                    newdir
                 )
             )
         return None
@@ -292,7 +264,7 @@ def ensure_mkdir_p(mode=0o777):
     # type: (int) -> Callable[Callable[..., Any], Callable[..., Any]]
     """Decorator to ensure `mkdir_p` is called to the function's return
     value."""
-
+    # This exists in shutil already
     def decorator(f):
         # type: (Callable[..., Any]) -> Callable[..., Any]
         @functools.wraps(f)
@@ -301,9 +273,7 @@ def ensure_mkdir_p(mode=0o777):
             path = f(*args, **kwargs)
             mkdir_p(path, mode=mode)
             return path
-
         return decorated
-
     return decorator
 
 
@@ -338,8 +308,7 @@ def create_tracked_tempfile(*args, **kwargs):
     The return value is the file object.
     """
 
-    kwargs["wrapper_class_override"] = _TrackedTempfileWrapper
-    return _NamedTemporaryFile(*args, **kwargs)
+    return NamedTemporaryFile(*args, **kwargs)
 
 
 def _find_icacls_exe():
@@ -359,16 +328,13 @@ def _find_icacls_exe():
     return None
 
 
-def set_write_bit(fn):
-    # type: (str) -> None
+def set_write_bit(fn: str) -> None:
     """Set read-write permissions for the current user on the target path. Fail
     silently if the path doesn't exist.
 
     :param str fn: The target filename or path
     :return: None
     """
-
-    fn = fs_decode(fs_encode(fn))
     if not os.path.exists(fn):
         return
     file_stat = os.stat(fn).st_mode
@@ -424,8 +390,9 @@ def set_write_bit(fn):
             set_write_bit(file_)
 
 
-def rmtree(directory, ignore_errors=False, onerror=None):
-    # type: (str, bool, Optional[Callable]) -> None
+def rmtree(directory: str,
+           ignore_errors: bool = False,
+           onerror: Optional[Callable] = None) -> None :
     """Stand-in for :func:`~shutil.rmtree` with additional error-handling.
 
     This version of `rmtree` handles read-only paths, especially in the case of index
@@ -440,7 +407,6 @@ def rmtree(directory, ignore_errors=False, onerror=None):
        Setting `ignore_errors=True` may cause this to silently fail to delete the path
     """
 
-    directory = fs_decode(fs_encode(directory))
     if onerror is None:
         onerror = handle_remove_readonly
     try:
@@ -498,8 +464,6 @@ def handle_remove_readonly(func, path, exc):
     This function will call check :func:`is_readonly_path` before attempting to call
     :func:`set_write_bit` on the target path and try again.
     """
-    # Check for read-only attribute
-    from .compat import ResourceWarning, FileNotFoundError, PermissionError
 
     PERM_ERRORS = (errno.EACCES, errno.EPERM, errno.ENOENT)
     default_warning_message = "Unable to remove file due to permissions restriction: {!r}"
@@ -611,11 +575,9 @@ def get_converted_relative_path(path, relative_to=None):
     from .misc import to_text, to_bytes  # noqa
 
     if not relative_to:
-        relative_to = os.getcwdu() if six.PY2 else os.getcwd()
-    if six.PY2:
-        path = to_bytes(path, encoding="utf-8")
-    else:
-        path = to_text(path, encoding="utf-8")
+        relative_to = os.getcwd()
+
+    path = to_text(path, encoding="utf-8")
     relative_to = to_text(relative_to, encoding="utf-8")
     start_path = Path(relative_to)
     try:
@@ -645,31 +607,6 @@ def get_converted_relative_path(path, relative_to=None):
 def safe_expandvars(value):
     # type: (TPath) -> str
     """Call os.path.expandvars if value is a string, otherwise do nothing."""
-    if isinstance(value, six.string_types):
+    if isinstance(value, str):
         return os.path.expandvars(value)
     return value  # type: ignore
-
-
-class _TrackedTempfileWrapper(_TemporaryFileWrapper, object):
-    def __init__(self, *args, **kwargs):
-        super(_TrackedTempfileWrapper, self).__init__(*args, **kwargs)
-        self._finalizer = finalize(self, self.cleanup)
-
-    @classmethod
-    def _cleanup(cls, fileobj):
-        try:
-            fileobj.close()
-        finally:
-            os.unlink(fileobj.name)
-
-    def cleanup(self):
-        if self._finalizer.detach():
-            try:
-                self.close()
-            finally:
-                os.unlink(self.name)
-        else:
-            try:
-                self.close()
-            except OSError:
-                pass
